@@ -8,8 +8,8 @@ function(mod){
   obs_cooccur <- ptab$obs_cooccur
   signs <- ptab$signs
   
-  p <- ggplot(ptab, aes(x=exp_cooccur, y=obs_cooccur)) + geom_point(aes(fill=as.character(signs)), colour="black",pch=21, size=5)
-  p <- p + scale_fill_manual(values = c("#FFCC66","dark gray","light blue"), name = "", labels = c("negative","random","positive")) 
+  p <- ggplot(ptab, aes(x=exp_cooccur, y=obs_cooccur)) + geom_point(aes(fill=factor(signs,levels=c(-1,0,1))), colour="black",pch=21, size=5)
+  p <- p + scale_fill_manual(values = c("#FFCC66","dark gray","light blue"), name = "", labels = c("negative","random","positive"),drop=FALSE) 
   p <- p + theme(plot.title = element_text(vjust=2,size=20, face="bold"),legend.text=element_text(size=18),axis.title = element_text(size = 20),axis.text=element_text(size=18),axis.text.x=element_text(hjust=0,vjust=1)) + xlab("Expected Co-occurrences") + ylab("Observed Co-occurrences")
   p <- p + ggtitle("Observed-Expected Plot") + geom_abline(color="dark gray")
   p
